<?php
/**
 * Registro00SEFIP.
 *
 * @package Logic
 * @author  alessandrobartels
 *
 */
class Registro00SEFIP extends RegistroSEFIP{

    const REGISTRO_00 = '00';
    const GFIP = '1';
    // Implementacao futura.
    const DERF = '3';
    const MODALIDADE_BRANCO = 'BRANCO';

    const CARACTER_HIFEN = ' - ';

    private $_pessoaResp;
    private $_estruturaResp;
    private $_nrRecolhimento;
    private $_modalidade;
    private $_competencia13;
    private $_nrInscricao;
    private $_tpInscricao;
    private $_idRecolhimentoFGTS;
    private $_dtFGTS;
    private $_idRecolhimentoGPS;
    private $_dtGPS;


    /**
     * Preparacao para a criacao do Registro 00.
     *
     * @param GpepessoaEntity $pessoa      Instancia de GpepessoaEntity.
     * @param string          $tpInscricao Tipo de inscricao da empresa responsavel pela geracao do arquivo.
     * @param string          $nrInscricao Numero de inscricao da empresa responsavel pela geracao do arquivo.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function geraRegistro00(){
        $this->_nrRecolhimento = $this->getCodigoRecolhimento();
        $this->_modalidade = $this->getModalidade();
        $this->_competencia13 =  $this->getCompetencia13();
        $this->_geraRegistro(self::REGISTRO_00);
    }


    /**
     * Cria o Registro 00.
     *
     * @param string $tpRegistro  Tipo de registro que sera criado.
     * @param string $tpInscricao Tipo de inscricao da empresa.
     * @param string $nrInscricao Numero de inscricao da empresa.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    private function _geraRegistro($tpRegistro){

        // Bloco 1 | 001-002 | Tipo do Registro.
        $this->atribuiDado($tpRegistro, 2);

        // Bloco 2 | 003-053 | Preencher com branco.
        $this->atribuiDado(parent::CARACTER_VAZIO, 51, parent::CARACTER_BRANCO);

        // Bloco 3 | 054 | Tipo de Remessa.
        $this->atribuiDado(self::GFIP, 1);

        // Bloco 4 | 055 | Tipo de Inscricao.
        $this->atribuiDado($this->_tpInscricao, 1);

        // Bloco 5 | 056-069 | Numero Inscricao do Responsavel.
        $this->atribuiDado($this->_nrInscricao, 14, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 6 | 070-099 | Nome do Responsavel.
        // @todo Verificar se pode vir como parametro no formulario.
        //$nomeResponsavel = 'TEKNISA SOFTWARE LTDA';
        $this->_atribuiRazaoSocial($this->_estruturaResp->historico->getNmrazsocestrut());
        //$nomeResponsavel = $this->_estruturaResp->historico->getNmrazsocestrut();
        //$this->atribuiDado($nomeResponsavel, 30, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 7 | 100-119 | Nome Pessoa Contato.
        // @todo Verificar se pode vir como parametro no formulario.
//        $nomePessoa = 'RAIMUNDO SANDI PENNA';
        $nomePessoa = $this->_pessoaResp->historico->getNmpessoa();
        $this->atribuiDado($nomePessoa, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 8 | 120-169 | Endereco do Responsavel.
        // @todo Verificar se pode vir como parametro no formulario.
//        $endereco = 'RUA GONCALVES DIAS 603';
        $endereco = $this->_estruturaResp->endereco->getDsendereco();
        $this->atribuiDado($endereco, 50, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 9 | 170-189 | Bairro do Responsavel.
        // @todo Verificar se pode vir como parametro no formulario.
//        $bairro = 'FUNCIONARIOS';
        $bairro = $this->_estruturaResp->endereco->bairro;
        $this->atribuiDado($bairro, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 10 | 190-197 | CEP. @todo Diferentes de 20000000, 30000000, 70000000 ou 80000000.
        // @todo Verificar se pode vir como parametro no formulario.
//        $cep = '30140090';
        $cep = $this->_estruturaResp->endereco->getNrcependereco();
        $this->atribuiDado($cep, 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 11 | 198-217 | Cidade.
        // @todo Verificar se pode vir como parametro no formulario.
//        $cidade = 'BELO HORIZONTE';
        $cidade = $this->_estruturaResp->endereco->municipio;
        $this->atribuiDado($cidade, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 12 | 218-219 | Estado.
        // @todo Verificar se pode vir como parametro no formulario.
//        $estado = 'MG';
        $estado = $this->_estruturaResp->endereco->getSgestado();
        $this->atribuiDado($estado, 2, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 13 | 220-231 | Telefone.
        // @todo Verificar se pode vir como parametro no formulario.
//        $telefone = '3121222300';
        $telefone = $this->_estruturaResp->endereco->ddd.$this->_estruturaResp->endereco->telefone;
        $this->atribuiDado($telefone, 12, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 14 | 232-291 | Endereco eletronico (e-mail).
        // @todo Verificar se pode vir como parametro no formulario.
//        $enderecoEletronico = 'contabilidade@teknisa.com';
        $enderecoEletronico = $this->_estruturaResp->endereco->email;
        $this->atribuiDadoEspecial($enderecoEletronico, 60, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 15 | 292-297 | Competencia (data AAAAMM).
        $competencia = $this->getCompetencia();
        $this->atribuiDado($competencia, 6, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 16 | 298-300 | Codigo de recolhimento.
        $this->atribuiDado($this->_nrRecolhimento, 3);

        // Bloco 17 | 301 | Indicador de recolhimento FGTS.
        $this->_atribuiRecolhimentoFGTS();

        // Bloco 18 | 302 | Modalidade do arquivo. @todo verificar layout.
        // $modalidade = 1; // <<<< Teste - retirar.
        $this->_atribuiModalidade();

        // Bloco 19 | 303-310 | Data recolhimento FGTS (DDMMAAAA).
        $this->_atribuiDataRecolhimentoFGTS();

        // Bloco 20 | 311 | Indicador de recolhimento da previdencia social.
        $this->_atribuiRecolhimentoGPS();

        // Bloco 21 | 312-319 | Data de recolhimento da GPS.
        $this->_atribuiDataRecolhimentoGPS();

        // Bloco 22 | 320-326 | Indice de recolhimento em atraso GPS - Deve ficar em branco.
        $this->atribuiDado(parent::CARACTER_VAZIO, 7, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 23 | 327 | Tipo de inscricao do fornecedor folha de pagamento. @todo verificar layout.
        /* De acordo com informação da caixa deve ser informado o tipo de inscrição da empresa que
         * desenvolveu o software da folha de pagamento
         */
        $tipoInscricaoFornecedor  = '1';
        $this->_atribuiTipoInscricaoFornecedor($tipoInscricaoFornecedor);

        // Bloco 24 | 328-341 | Inscricao do fornecedor Folha de Pagamento.
        /* De acordo com informação da caixa deve ser informado o numero de inscrição da empresa que
         * desenvolveu o software da folha de pagamento - CNPJ Teknisa
         */
        $inscricaoFornecedor = '26269316000177';
        $this->atribuiDado($inscricaoFornecedor, 14, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 25 | 342-359 | Brancos. Preencher com ' '.
        $this->atribuiDado(parent::CARACTER_VAZIO, 18, parent::CARACTER_BRANCO);

        // Bloco 26 | 360 | Final de linha. Inserir '*'.
        $this->atribuiDado(parent::CARACTER_VAZIO, 1, parent::CARACTER_ASTERISCO);

    }

    public function setNrInscricao($nrInscricao){
        $this->_nrInscricao = $nrInscricao;
    }

    public function setTpInscricao($tpInscricao){
        $this->_tpInscricao = $tpInscricao;
    }

    public function setPessoaResp($pessoaResp){
        $this->_pessoaResp = $pessoaResp;
    }

    public function setEstruturaResp($estruturaResp){
        $this->_estruturaResp = $estruturaResp;
    }

    public function setIdRecolhimentoFGTS($idRecolhimentoFGTS) {
        $this->_idRecolhimentoFGTS = $idRecolhimentoFGTS;
    }

    public function setDtFGTS($dtFGTS) {
        $this->_dtFGTS = $dtFGTS;
    }

    public function setIdRecolhimentoGPS($idRecolhimentoGPS) {
        $this->_idRecolhimentoGPS = $idRecolhimentoGPS;
    }

    public function setDtGPS($dtGPS) {
        $this->_dtGPS = $dtGPS;
    }


    /**
     * Atribui Recolhimento FGTS.
     *
     * @return void
     *
     * @author alessandrobartels
     *         alessandrobartels - 17/04/2012 - validacao
     */
    private function _atribuiRecolhimentoFGTS(){

        if (($this->_nrRecolhimento !== '211') && ($this->_competencia13 === false) ) {
            $idRecolhimentoFGTS = $this->_idRecolhimentoFGTS;
        } else {
            $idRecolhimentoFGTS = parent::CARACTER_BRANCO;
        }

        $this->atribuiDado($idRecolhimentoFGTS, 1);
    }


    /**
     * Enter description here ...
     *
     * @return void
     *
     * @author alessandrobartels
     */
    private function _atribuiModalidade(){
        // @todo verificar layout e arquivo ARTE para validacoes.
        if ($this->_modalidade === self::MODALIDADE_BRANCO){
            $this->_modalidade = self::CARACTER_BRANCO;
        }

        $this->atribuiDado($this->_modalidade, 1);
    }

    private function _atribuiRazaoSocial($razaosocial){
        $razaosocialtradado = str_replace(self::CARACTER_HIFEN, parent::CARACTER_BRANCO, $razaosocial);
        $this->atribuiDado($razaosocialtradado, 30, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
    }


    /**
     * Enter description here ...
     *
     * @return void
     *
     * @author alessandrobartels - 17/04/2012
     */
    private function _atribuiDataRecolhimentoFGTS(){

        $dataFGTS = parent::CARACTER_BRANCO;

        if ($this->_idRecolhimentoFGTS !== 1) {
            if (empty($this->_dtFGTS) !== true){

                $dataFGTS = new TkDateTime($this->_dtFGTS);
                $dataFGTS = $dataFGTS->toString(TkDateTime::DAY.TkDateTime::MONTH.TkDateTime::YEAR);
            }
        }

        $this->atribuiDado($dataFGTS, 8, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
    }


    /**
     * Enter description here ...
     *
     * @return void
     *
     * @author alessandrobartels
     *         alessandrobartels - 17/04/2012 - validacao
     */
    private function _atribuiRecolhimentoGPS(){
        // @todo verificar layout e arquivo ARTE para validacoes.
        // (1 = no prazo | 2 = em atraso | 3 = nao gera GPS).
        $this->atribuiDado($this->_idRecolhimentoGPS, 1);
    }


    /**
     * Enter description here ...
     *
     * @return void
     *
     * @author alessandrobartels - 17/04/2012
     */
    private function _atribuiDataRecolhimentoGPS(){

        $dataGPS = parent::CARACTER_BRANCO;

        if ($this->_idRecolhimentoGPS !== 1) {
            if (empty($this->_dtGPS) !== true){

                $dataGPS = new TkDateTime($this->_dtGPS);
                $dataGPS = $dataGPS->toString(TkDateTime::DAY.TkDateTime::MONTH.TkDateTime::YEAR);
            }
        }

        $this->atribuiDado($dataGPS, 8, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
    }

    /**
     * Enter description here ...
     *
     * @param string $tipoInscricaoFornecedor Tipo de inscricao do fornecedor.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    private function _atribuiTipoInscricaoFornecedor($tipoInscricaoFornecedor){
        // @todo verificar layout e arquivo ARTE para validacoes.
        $this->atribuiDado($tipoInscricaoFornecedor, 1); // Criar constante.
    }





}